var annotated_dup =
[
    [ "Steinberg", "namespaceSteinberg.html", [
      [ "OneReaderOneWriter", "namespaceSteinberg_1_1OneReaderOneWriter.html", [
        [ "RingBuffer", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer" ]
      ] ],
      [ "PluginFactoryDetail", "namespaceSteinberg_1_1PluginFactoryDetail.html", [
        [ "ClassInfo2WithCreateFunc", "structSteinberg_1_1PluginFactoryDetail_1_1ClassInfo2WithCreateFunc.html", "structSteinberg_1_1PluginFactoryDetail_1_1ClassInfo2WithCreateFunc" ]
      ] ],
      [ "Vst", null, [
        [ "InterAppAudio", "namespaceSteinberg_1_1Vst_1_1InterAppAudio.html", [
          [ "MidiIO", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO" ],
          [ "PresetManager", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager" ]
        ] ],
        [ "MPE", "namespaceSteinberg_1_1Vst_1_1MPE.html", [
          [ "Handler", "structSteinberg_1_1Vst_1_1MPE_1_1Handler.html", "structSteinberg_1_1Vst_1_1MPE_1_1Handler" ],
          [ "Processor", "classSteinberg_1_1Vst_1_1MPE_1_1Processor.html", "classSteinberg_1_1Vst_1_1MPE_1_1Processor" ],
          [ "Setup", "structSteinberg_1_1Vst_1_1MPE_1_1Setup.html", "structSteinberg_1_1Vst_1_1MPE_1_1Setup" ]
        ] ],
        [ "SampleAccurate", "namespaceSteinberg_1_1Vst_1_1SampleAccurate.html", [
          [ "Parameter", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter" ]
        ] ],
        [ "UMP", "namespaceSteinberg_1_1Vst_1_1UMP.html", [
          [ "Detail", "namespaceSteinberg_1_1Vst_1_1UMP_1_1Detail.html", [
            [ "UMPMessage", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessage.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessage" ],
            [ "UMPMessage2", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessage2.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessage2" ],
            [ "UMPMessage4", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessage4.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessage4" ],
            [ "UMPMessageChannelVoice1", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageChannelVoice1.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageChannelVoice1" ],
            [ "UMPMessageChannelVoice2", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageChannelVoice2.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageChannelVoice2" ],
            [ "UMPMessageData128", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageData128.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageData128" ],
            [ "UMPMessageSysEx", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageSysEx.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageSysEx" ],
            [ "UMPMessageSystem", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageSystem.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageSystem" ],
            [ "UMPMessageUtility", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageUtility.html", "structSteinberg_1_1Vst_1_1UMP_1_1Detail_1_1UMPMessageUtility" ]
          ] ],
          [ "IUniversalMidiPacketHandler", "structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler.html", "structSteinberg_1_1Vst_1_1UMP_1_1IUniversalMidiPacketHandler" ],
          [ "UniversalMidiPacketHandlerAdapter", "structSteinberg_1_1Vst_1_1UMP_1_1UniversalMidiPacketHandlerAdapter.html", "structSteinberg_1_1Vst_1_1UMP_1_1UniversalMidiPacketHandlerAdapter" ]
        ] ],
        [ "AudioBuffer", "classSteinberg_1_1Vst_1_1AudioBuffer.html", "classSteinberg_1_1Vst_1_1AudioBuffer" ],
        [ "AudioBus", "classSteinberg_1_1Vst_1_1AudioBus.html", "classSteinberg_1_1Vst_1_1AudioBus" ],
        [ "AudioEffect", "classSteinberg_1_1Vst_1_1AudioEffect.html", "classSteinberg_1_1Vst_1_1AudioEffect" ],
        [ "BufferStream", "classSteinberg_1_1Vst_1_1BufferStream.html", "classSteinberg_1_1Vst_1_1BufferStream" ],
        [ "Bus", "classSteinberg_1_1Vst_1_1Bus.html", "classSteinberg_1_1Vst_1_1Bus" ],
        [ "BusList", "classSteinberg_1_1Vst_1_1BusList.html", "classSteinberg_1_1Vst_1_1BusList" ],
        [ "BypassProcessor", "classSteinberg_1_1Vst_1_1BypassProcessor.html", "classSteinberg_1_1Vst_1_1BypassProcessor" ],
        [ "Component", "classSteinberg_1_1Vst_1_1Component.html", "classSteinberg_1_1Vst_1_1Component" ],
        [ "ComponentBase", "classSteinberg_1_1Vst_1_1ComponentBase.html", "classSteinberg_1_1Vst_1_1ComponentBase" ],
        [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", "classSteinberg_1_1Vst_1_1ConnectionProxy" ],
        [ "DataExchangeHandler", "classSteinberg_1_1Vst_1_1DataExchangeHandler.html", "classSteinberg_1_1Vst_1_1DataExchangeHandler" ],
        [ "DataExchangeReceiverHandler", "classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html", "classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler" ],
        [ "EditController", "classSteinberg_1_1Vst_1_1EditController.html", "classSteinberg_1_1Vst_1_1EditController" ],
        [ "EditControllerEx1", "classSteinberg_1_1Vst_1_1EditControllerEx1.html", "classSteinberg_1_1Vst_1_1EditControllerEx1" ],
        [ "EditorView", "classSteinberg_1_1Vst_1_1EditorView.html", "classSteinberg_1_1Vst_1_1EditorView" ],
        [ "EventBus", "classSteinberg_1_1Vst_1_1EventBus.html", "classSteinberg_1_1Vst_1_1EventBus" ],
        [ "EventList", "classSteinberg_1_1Vst_1_1EventList.html", "classSteinberg_1_1Vst_1_1EventList" ],
        [ "FileStream", "classSteinberg_1_1Vst_1_1FileStream.html", "classSteinberg_1_1Vst_1_1FileStream" ],
        [ "HostApplication", "classSteinberg_1_1Vst_1_1HostApplication.html", "classSteinberg_1_1Vst_1_1HostApplication" ],
        [ "HostAttributeList", "classSteinberg_1_1Vst_1_1HostAttributeList.html", "classSteinberg_1_1Vst_1_1HostAttributeList" ],
        [ "HostDataExchangeHandler", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler" ],
        [ "HostMessage", "classSteinberg_1_1Vst_1_1HostMessage.html", "classSteinberg_1_1Vst_1_1HostMessage" ],
        [ "HostProcessData", "classSteinberg_1_1Vst_1_1HostProcessData.html", "classSteinberg_1_1Vst_1_1HostProcessData" ],
        [ "IDataExchangeHandlerHost", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost" ],
        [ "NoteExpressionType", "classSteinberg_1_1Vst_1_1NoteExpressionType.html", "classSteinberg_1_1Vst_1_1NoteExpressionType" ],
        [ "NoteExpressionTypeContainer", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html", "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer" ],
        [ "ParamChanges", "classSteinberg_1_1Vst_1_1ParamChanges.html", "classSteinberg_1_1Vst_1_1ParamChanges" ],
        [ "Parameter", "classSteinberg_1_1Vst_1_1Parameter.html", "classSteinberg_1_1Vst_1_1Parameter" ],
        [ "ParameterChanges", "classSteinberg_1_1Vst_1_1ParameterChanges.html", "classSteinberg_1_1Vst_1_1ParameterChanges" ],
        [ "ParameterChangeTransfer", "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html", "classSteinberg_1_1Vst_1_1ParameterChangeTransfer" ],
        [ "ParameterContainer", "classSteinberg_1_1Vst_1_1ParameterContainer.html", "classSteinberg_1_1Vst_1_1ParameterContainer" ],
        [ "ParameterValueQueue", "classSteinberg_1_1Vst_1_1ParameterValueQueue.html", "classSteinberg_1_1Vst_1_1ParameterValueQueue" ],
        [ "ParamPoint", "classSteinberg_1_1Vst_1_1ParamPoint.html", "classSteinberg_1_1Vst_1_1ParamPoint" ],
        [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", "classSteinberg_1_1Vst_1_1PluginContextFactory" ],
        [ "PlugInterfaceSupport", "classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html", "classSteinberg_1_1Vst_1_1PlugInterfaceSupport" ],
        [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", "classSteinberg_1_1Vst_1_1PlugProvider" ],
        [ "PresetFile", "classSteinberg_1_1Vst_1_1PresetFile.html", "classSteinberg_1_1Vst_1_1PresetFile" ],
        [ "ProcessContextRequirements", "classSteinberg_1_1Vst_1_1ProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1ProcessContextRequirements" ],
        [ "ProcessDataSlicer", "classSteinberg_1_1Vst_1_1ProcessDataSlicer.html", "classSteinberg_1_1Vst_1_1ProcessDataSlicer" ],
        [ "ProgramList", "classSteinberg_1_1Vst_1_1ProgramList.html", "classSteinberg_1_1Vst_1_1ProgramList" ],
        [ "ProgramListWithPitchNames", "classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html", "classSteinberg_1_1Vst_1_1ProgramListWithPitchNames" ],
        [ "RangeNoteExpressionType", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType.html", "classSteinberg_1_1Vst_1_1RangeNoteExpressionType" ],
        [ "RangeParameter", "classSteinberg_1_1Vst_1_1RangeParameter.html", "classSteinberg_1_1Vst_1_1RangeParameter" ],
        [ "ReadOnlyBStream", "classSteinberg_1_1Vst_1_1ReadOnlyBStream.html", "classSteinberg_1_1Vst_1_1ReadOnlyBStream" ],
        [ "RTTransferT", "structSteinberg_1_1Vst_1_1RTTransferT.html", "structSteinberg_1_1Vst_1_1RTTransferT" ],
        [ "SingleComponentEffect", "classSteinberg_1_1Vst_1_1SingleComponentEffect.html", "classSteinberg_1_1Vst_1_1SingleComponentEffect" ],
        [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", "classSteinberg_1_1Vst_1_1SpeakerArray" ],
        [ "StringListParameter", "classSteinberg_1_1Vst_1_1StringListParameter.html", "classSteinberg_1_1Vst_1_1StringListParameter" ],
        [ "StringResult", "classSteinberg_1_1Vst_1_1StringResult.html", "classSteinberg_1_1Vst_1_1StringResult" ],
        [ "SystemTime", "classSteinberg_1_1Vst_1_1SystemTime.html", "classSteinberg_1_1Vst_1_1SystemTime" ],
        [ "TestBase", "classSteinberg_1_1Vst_1_1TestBase.html", "classSteinberg_1_1Vst_1_1TestBase" ],
        [ "TestDefaults", "structSteinberg_1_1Vst_1_1TestDefaults.html", "structSteinberg_1_1Vst_1_1TestDefaults" ],
        [ "TestEnh", "classSteinberg_1_1Vst_1_1TestEnh.html", "classSteinberg_1_1Vst_1_1TestEnh" ],
        [ "TestingPluginContext", "structSteinberg_1_1Vst_1_1TestingPluginContext.html", null ],
        [ "ThreadChecker", "classSteinberg_1_1Vst_1_1ThreadChecker.html", "classSteinberg_1_1Vst_1_1ThreadChecker" ],
        [ "Unit", "classSteinberg_1_1Vst_1_1Unit.html", "classSteinberg_1_1Vst_1_1Unit" ],
        [ "VSTGUIEditor", "classSteinberg_1_1Vst_1_1VSTGUIEditor.html", "classSteinberg_1_1Vst_1_1VSTGUIEditor" ],
        [ "XmlRepresentationHelper", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper.html", "classSteinberg_1_1Vst_1_1XmlRepresentationHelper" ]
      ] ],
      [ "CPluginFactory", "classSteinberg_1_1CPluginFactory.html", "classSteinberg_1_1CPluginFactory" ],
      [ "CPluginView", "classSteinberg_1_1CPluginView.html", "classSteinberg_1_1CPluginView" ],
      [ "IPluginFactoryInternal", "classSteinberg_1_1IPluginFactoryInternal.html", "classSteinberg_1_1IPluginFactoryInternal" ],
      [ "MemoryStream", "classSteinberg_1_1MemoryStream.html", "classSteinberg_1_1MemoryStream" ],
      [ "ModuleInfo", "structSteinberg_1_1ModuleInfo.html", "structSteinberg_1_1ModuleInfo" ],
      [ "ModuleInitializer", "structSteinberg_1_1ModuleInitializer.html", "structSteinberg_1_1ModuleInitializer" ],
      [ "ModuleTerminator", "structSteinberg_1_1ModuleTerminator.html", "structSteinberg_1_1ModuleTerminator" ],
      [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", "structSteinberg_1_1ObjCClassBuilder" ],
      [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", "structSteinberg_1_1ObjCInstance" ],
      [ "ObjCVariable", "structSteinberg_1_1ObjCVariable.html", "structSteinberg_1_1ObjCVariable" ],
      [ "PluginFactory", "classSteinberg_1_1PluginFactory.html", "classSteinberg_1_1PluginFactory" ],
      [ "ResizableMemoryIBStream", "classSteinberg_1_1ResizableMemoryIBStream.html", "classSteinberg_1_1ResizableMemoryIBStream" ]
    ] ],
    [ "VST3", "namespaceVST3.html", [
      [ "Hosting", "namespaceVST3_1_1Hosting.html", [
        [ "ClassInfo", "classVST3_1_1Hosting_1_1ClassInfo.html", "classVST3_1_1Hosting_1_1ClassInfo" ],
        [ "FactoryInfo", "classVST3_1_1Hosting_1_1FactoryInfo.html", "classVST3_1_1Hosting_1_1FactoryInfo" ],
        [ "Module", "classVST3_1_1Hosting_1_1Module.html", "classVST3_1_1Hosting_1_1Module" ],
        [ "PluginFactory", "classVST3_1_1Hosting_1_1PluginFactory.html", "classVST3_1_1Hosting_1_1PluginFactory" ]
      ] ],
      [ "Optional", "structVST3_1_1Optional.html", "structVST3_1_1Optional" ],
      [ "UID", "structVST3_1_1UID.html", "structVST3_1_1UID" ],
      [ "Version", "structVST3_1_1Version.html", "structVST3_1_1Version" ],
      [ "Vst2xProgram", "structVST3_1_1Vst2xProgram.html", "structVST3_1_1Vst2xProgram" ],
      [ "Vst2xState", "structVST3_1_1Vst2xState.html", "structVST3_1_1Vst2xState" ]
    ] ],
    [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", "interfaceVSTInterAppAudioAppDelegateBase" ]
];